EXPORTS
	?GetControllerSessionHandle@RMMFDRMPluginServerProxy@@QAEHXZ @ 1 NONAME ; int RMMFDRMPluginServerProxy::GetControllerSessionHandle(void)
	?LaunchControllerServer@RMMFDRMPluginServerProxy@@QAEHIHAAVTThreadId@@I@Z @ 2 NONAME ; int RMMFDRMPluginServerProxy::LaunchControllerServer(unsigned int, int, class TThreadId &, unsigned int)
	?Open@RMMFDRMPluginServerProxy@@QAEHXZ @ 3 NONAME ; int RMMFDRMPluginServerProxy::Open(void)
	?KillControllerThread@RMMFDRMPluginServerProxy@@QAEHVTThreadId@@H@Z @ 4 NONAME ; int RMMFDRMPluginServerProxy::KillControllerThread(class TThreadId, int)
	?PanicControllerThread@RMMFDRMPluginServerProxy@@QAEHVTThreadId@@ABVTDesC16@@H@Z @ 5 NONAME ; int RMMFDRMPluginServerProxy::PanicControllerThread(class TThreadId, class TDesC16 const &, int)
	?SetThreadPriority@RMMFDRMPluginServerProxy@@QAEHVTThreadId@@W4TThreadPriority@@@Z @ 6 NONAME ; int RMMFDRMPluginServerProxy::SetThreadPriority(class TThreadId, enum TThreadPriority)
	?OpenDataContentL@RMMFDRMPluginServerProxy@@QAEXABVRFile@@ABVTDesC8@@@Z @ 7 NONAME ; void RMMFDRMPluginServerProxy::OpenDataContentL(class RFile const &, class TDesC8 const &)
	?OpenDataContentL@RMMFDRMPluginServerProxy@@QAEXABVTDesC16@@ABVTDesC8@@@Z @ 8 NONAME ; void RMMFDRMPluginServerProxy::OpenDataContentL(class TDesC16 const &, class TDesC8 const &)
	?EvaluateDataContentIntent@RMMFDRMPluginServerProxy@@QAEHW4TIntent@ContentAccess@@@Z @ 9 NONAME ; int RMMFDRMPluginServerProxy::EvaluateDataContentIntent(enum ContentAccess::TIntent)
	?GetDataContentFileHeaderL@RMMFDRMPluginServerProxy@@QAEXAAVTDes8@@H@Z @ 10 NONAME ; void RMMFDRMPluginServerProxy::GetDataContentFileHeaderL(class TDes8 &, int)
	?GetDataContentMimeTypeL@RMMFDRMPluginServerProxy@@QAEHAAVTDes8@@@Z @ 11 NONAME ; int RMMFDRMPluginServerProxy::GetDataContentMimeTypeL(class TDes8 &)
	?KMmfDrmPluginServerTimeOut@@3HB @ 12 NONAME ; int const KMmfDrmPluginServerTimeOut

